@@ -320,3 +320,17 @@ void PuntateMain::on_stream20_clicked()
     process.start("sh /opt/serviziopubblico/script/p20.sh");
     process.waitForFinished();
 }
+
+void PuntateMain::on_down21_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/d21.sh");
+    process.waitForFinished();
+}
+
+void PuntateMain::on_stream21_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/p21.sh");
+    process.waitForFinished();
+}
