@@ -100,6 +100,10 @@ private slots:
 
     void on_stream20_clicked();
 
+    void on_down21_clicked();
+
+    void on_stream21_clicked();
+
 private:
     Ui::PuntateMain *ui;
 };
